@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = '0.31_09';
+$VERSION = '0.31_10';
 
 # This allows declaration       use UUID ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
@@ -18,7 +18,8 @@ $VERSION = '0.31_09';
 %EXPORT_TAGS = (
     'all' => [qw(
         &clear &compare &copy &generate &generate_random &generate_time
-        &is_null &parse &unparse &unparse_lower &unparse_upper &uuid
+        &is_null &parse &time &type &unparse &unparse_lower
+        &unparse_upper &uuid &variant
     )],
 );
 
@@ -57,6 +58,11 @@ UUID - DCE compatible Universally Unique Identifier library for Perl
     UUID::clear( $uuid );                # set binary UUID to NULL
     UUID::is_null( $uuid );              # compare binary UUID to NULL
 
+    UUID::type( $uuid );                 # return UUID type
+    UUID::variant( $uuid );              # return UUID variant
+
+    UUID::time( $uuid );                 # return internal UUID time
+
 
 =head1 DESCRIPTION
 
@@ -82,13 +88,33 @@ not very likely to change any time soon.
 All take or return UUIDs in either binary or string format. The string
 format resembles the following:
 
-    1b4e28ba-2fa1-11d2-883f-0016d3cca427
+    21b081a3-de83-4480-a14f-e89a1dcf8f0f
 
 Or, in terms of printf(3) format:
 
     "%08x-%04x-%04x-%04x-%012x"
 
-The binary format is simply a packed 16 byte binary value.
+The binary form is simply a packed 16 byte binary value.
+
+=head2 B<clear(> I<$uuid> B<)>
+
+Sets I<$uuid> equal to the value of the NULL UUID.
+
+=head2 B<copy(> I<$dst>B<,> I<$src> B<)>
+
+Copies the binary I<$src> UUID to I<$dst>.
+
+If I<$src> isn't a UUID, I<$dst> is set to the NULL UUID.
+
+=head2 B<compare(> I<$uuid1>B<,> I<$uuid2> B<)>
+
+Compares two binary UUIDs.
+
+Returns an integer less than, equal to, or greater than zero if
+I<$uuid1> is less than, equal to, or greater than I<$uuid2>.
+
+However, if either operand is not a UUID, falls back to a simple string
+comparison returning similar values.
 
 =head2 B<generate(> I<$uuid> B<)>
 
@@ -125,6 +151,31 @@ This can cause privacy problems in some applications, so the B<generate()>
 function only uses this algorithm if a high-quality source of randomness
 is not available.
 
+=head2 B<is_null(> I<$uuid> B<)>
+
+Compares the value of I<$uuid> to the NULL UUID.
+
+Returns 1 if NULL, and 0 otherwise.
+
+=head2 B<parse(> I<$string>B<,> I<$uuid> B<)>
+
+Converts the string format UUID in I<$string> to binary and returns in
+I<$uuid>. The previous content of I<$uuid>, if any, is lost.
+
+Returns 0 on success and -1 on failure. Additionally on failure, the
+content of I<$uuid> is unchanged.
+
+=head2 B<time(> I<$uuid> B<)>
+
+...
+
+=head2 B<type(> I<$uuid> B<)>
+
+Returns the type of binary I<$uuid>.
+
+This module only generates type 1 (time) and type 4 (random) UUIDs, but
+others may be found in the wild.
+
 =head2 B<unparse(> I<$uuid>B<,> I<$string> B<)>
 
 Converts the binary UUID in I<$uuid> to string format and returns in
@@ -141,47 +192,27 @@ Same as B<unparse()> but I<$string> is forced to lower case.
 
 Same as B<unparse()> but I<$string> is forced to upper case.
 
-=head2 B<$rc = parse(> I<$string>B<,> I<$uuid> B<)>
-
-Converts the string format UUID in I<$string> to binary and returns in
-I<$uuid>. The previous content of I<$uuid>, if any, is lost.
-
-Returns 0 on success and -1 on failure. Additionally on failure, the
-content of I<$uuid> is unchanged.
-
-=head2 B<clear(> I<$uuid> B<)>
-
-Sets I<$uuid> equal to the value of the NULL UUID.
-
-=head2 B<is_null(> I<$uuid> B<)>
-
-Compares the value of I<$uuid> to the NULL UUID.
-
-Returns 1 if NULL, and 0 otherwise.
-
-=head2 B<copy(> I<$dst>B<,> I<$src> B<)>
-
-Copies the binary I<$src> UUID to I<$dst>.
-
-If I<$src> isn't a UUID, I<$dst> is set to the NULL UUID.
-
-=head2 B<compare(> I<$uuid1>B<,> I<$uuid2> B<)>
-
-Compares two binary UUIDs.
-
-Returns an integer less than, equal to, or greater than zero if
-I<$uuid1> is less than, equal to, or greater than I<$uuid2>.
-
-However, if either operand is not a UUID, falls back to a simple string
-comparison returning similar values.
-
-=head2 B<>I<$string> B<= uuid()>
+=head2 B<uuid()>
 
 Creates a new string format UUID and returns it in a more Perlish way.
 
 Functionally the equivalent of calling B<generate()> and then B<unparse()>, but
 throwing away the intermediate binary UUID.
 
+=head2 B<variant(> I<$uuid> B<)>
+
+Returns the variant of binary I<$uuid>.
+
+This module only generates variant 1 UUIDs, but others may be found in
+the wild.
+
+Known variants:
+
+    0  NCS
+    1  DCE
+    2  Microsoft
+    3  Other
+
 =head1 UUID LIBRARY
 
 On some systems external packages will need to be installed first.
